@@ -818,10 +818,9 @@ void MainWindow::play_pause(){
 }
 
 void MainWindow::currentItemChanged ( QListWidgetItem * current ){
-    inet_source=0;
+    if (inet_source==0){
     if (moo->currentTime()/moo->totalTime()>0.5)
-        scrobler->addTrack(list.value(ui.listWidget->currentRow()),moo->totalTime());
-
+        scrobler->addTrack(list.value(ui.listWidget->currentRow()),moo->totalTime());}else inet_source=0;
     moo->setCurrentSource(list.value(ui.listWidget->row(current)).at(0));
     moo->play();
 
