@@ -29,6 +29,7 @@ public:
     //QStringList list;
     QMenu *mmenu;
     QMap<int,QStringList> list;
+    QMap<int,QStringList> ilist;
     QStringList queue;
     Phonon::MediaObject *metaInformationResolver;
     QProgressBar *loading;
@@ -51,8 +52,11 @@ public:
     int on_head_con;
     int on_head_dis;
     int on_start;
+    int inet_source;
 public slots:
-
+    void load_inet();
+    void inet(QListWidgetItem*);
+    void fmtx_change(int);
     void toggleEqualizer(bool);
     void sliderChanged (int);
     void resetAll ();
@@ -63,6 +67,13 @@ public slots:
     void click3();
     void click4();
     void click5();
+    void click6();
+    void click7();
+    void click8();
+
+
+    void i_fn_click();
+    void findi();
     void pl_sf_click();
     void pl_fn_click();
     void pl_fn_add_dir();
